@@ -15,6 +15,7 @@ var2 <- labelled::labelled_spss(
   na_range = c(8,12), 
   na_values = c(7,9))
 
+
 var3 <- labelled::labelled(
   x = c(1,0,1,1,0,8,9), 
   labels = c("TRUST" = 1, 
@@ -28,12 +29,16 @@ var4 <- labelled::labelled_spss(
 
 test_that("harmonization_works", {
   expect_equal(attr(na_range_to_values (x=var1),"na_values"),c(8,9))
-  expect_equal(attr(na_range_to_values(x=var2), "na_values"),c(7,9))
-  expect_equal(attr(na_range_to_values(x=var2), "na_range"), c(7,12))
   expect_equal(as_numeric(na_range_to_values(var4)), c(1,0,NA_real_))
   expect_equal(attr(na_range_to_values(x=var3), "na_values"),NULL)
 })
 
+
+test_that("harmonization_works2", {
+  suppressWarnings(expect_equal(attr(na_range_to_values(x=var2), "na_values"),c(7,9)))
+  suppressWarnings(expect_equal(attr(na_range_to_values(x=var2), "na_range"), c(7,12)))
+})
+
 test_that("warning works", {
   expect_warning(na_range_to_values(x=var2))
 })
